# bounds
Bounding box from raster, geographic coordinates.

Bounds is a simple class, originally implemented in [obsio](https://github.com/jaredwo/obsio) that takes a 
raster or the bounding latitude and longitude of an area of interest, and returns the bounding box,
optionally transfroming to/from geographic coordinates/projected coordinates.
